@@ -24,7 +24,8 @@ int createAuthHeader(const char *user,
                      const char *aka_AMF,
                      const char *aka_K,
                      unsigned int nonce_count,
-                     char *result);
+                     char *result,
+                     size_t result_len);
 int verifyAuthHeader(const char *user, const char *password,
                      const char *method, const char *auth,
                      const char *msgbody);
