@@ -63,6 +63,7 @@ extern char** environ;
 
 extern SIPpSocket *ctrl_socket;
 extern SIPpSocket *stdin_socket;
+static bool random_base_ssrc = false;
 
 /* These could be local to main, but for the option processing table. */
 static int argiFileName;
@@ -118,6 +119,8 @@ struct sipp_option {
 #define SIPP_OPTION_LFOVERWRITE   37
 #define SIPP_OPTION_PLUGIN        38
 #define SIPP_OPTION_NEED_SCTP     39
+#define SIPP_OPTION_RX_SCENARIO   40
+#define SIPP_OPTION_RX_INPUT_FILE 41
 #define SIPP_HELP_TEXT_HEADER    255
 
 /* Put each option, its help text, and type in this table. */
@@ -128,6 +131,9 @@ struct sipp_option options_table[] = {
     {"", "Scenario file options:", SIPP_HELP_TEXT_HEADER, nullptr, 0},
     {"sd", "Dumps a default scenario (embedded in the SIPp executable)", SIPP_OPTION_SCENARIO, nullptr, 0},
     {"sf", "Loads an alternate XML scenario file.  To learn more about XML scenario syntax, use the -sd option to dump embedded scenarios. They contain all the necessary help.", SIPP_OPTION_SCENARIO, nullptr, 2},
+    {"rxsf", "Loads an alternate receive xml scenario file as the second scenario - enabling a mixture of originating and terminating calls to be executed.\n"
+     "If this is included then the second scenario MUST be a server mode scenario, and the first scenario (specified in -sf / -sn) MUST be a client-mode scenario.\n"
+     "If both -snrx and -sfrx are omitted then only a single scenario is executed.", SIPP_OPTION_RX_SCENARIO, NULL, 2},
     {"oocsf", "Load out-of-call scenario.", SIPP_OPTION_OOC_SCENARIO, nullptr, 2},
     {"oocsn", "Load out-of-call scenario.", SIPP_OPTION_OOC_SCENARIO, nullptr, 2},
     {
@@ -144,6 +150,11 @@ struct sipp_option options_table[] = {
         "- '3pcc-A'   : A side.\n"
         "- '3pcc-B'   : B side.\n", SIPP_OPTION_SCENARIO, nullptr, 2
     },
+    {
+        "rxrn", "Use a default scenario (embedded in the sipp executable) for the second scenario - enabling a mixture of originating and terminating calls to be executed.\n"
+        "If this is included then the second scenario MUST be a server mode scenario, and the first scenario (specified in -sf / -sn) MUST be a client-mode scenario.\n"
+        "If both -snrx and -sfrx are omitted then only a single scenario is executed.\n", SIPP_OPTION_RX_SCENARIO, NULL, 2
+    },
 
     {"", "IP, port and protocol options:", SIPP_HELP_TEXT_HEADER, nullptr, 0},
         {
@@ -264,6 +275,9 @@ struct sipp_option options_table[] = {
 
 
     {"", "Injection file options:", SIPP_HELP_TEXT_HEADER, nullptr, 0},
+    {"rxinf", "Inject values from an external CSV file during calls into the scenarios.\n"
+     "First line of this file say whether the data is to be read in sequence (SEQUENTIAL), random (RANDOM), or user (USER) order.\n"
+      "Each line corresponds to one call and has one or more ';' delimited data fields. Those fields can be referred as [field0], [field1], ... in the xml scenario file.  Several CSV files can be used simultaneously (syntax: -inf f1.csv -inf f2.csv ...)", SIPP_OPTION_RX_INPUT_FILE, NULL, 1},
     {"inf", "Inject values from an external CSV file during calls into the scenarios.\n"
      "First line of this file say whether the data is to be read in sequence (SEQUENTIAL), random (RANDOM), or user (USER) order.\n"
      "Each line corresponds to one call and has one or more ';' delimited data fields. Those fields can be referred as [field0], [field1], ... in the xml scenario file.  Several CSV files can be used simultaneously (syntax: -inf f1.csv -inf f2.csv ...)", SIPP_OPTION_INPUT_FILE, nullptr, 1},
@@ -291,6 +305,7 @@ struct sipp_option options_table[] = {
 #endif // USE_TLS
     {"audiotolerance", "Audio error tolerance for RTP checks (0.0-1.0) -- default: 1.0", SIPP_OPTION_FLOAT, &audiotolerance, 1},
     {"videotolerance", "Video error tolerance for RTP checks (0.0-1.0) -- default: 1.0", SIPP_OPTION_FLOAT, &videotolerance, 1},
+    {"random_base_ssrc", "Use a random base SSRC for RTP streams instead of default value 0xCA110000", SIPP_OPTION_SETFLAG, &random_base_ssrc, 1},
 
     {"", "Call rate options:", SIPP_HELP_TEXT_HEADER, nullptr, 0},
     {"r", "Set the call rate (in calls per seconds).  This value can be"
@@ -364,6 +379,7 @@ struct sipp_option options_table[] = {
     {"stat_delimiter", "Set the delimiter for the statistics file", SIPP_OPTION_STRING, &stat_delimiter, 1},
     {"stf", "Set the file name to use to dump statistics", SIPP_OPTION_ARGI, &argiFileName, 1},
     {"fd", "Set the statistics dump log report frequency. Default is 60 and default unit is seconds.", SIPP_OPTION_TIME_SEC, &report_freq_dumpLog, 1},
+    {"rfc3339", "Use timestamps in RFC3339 format.", SIPP_OPTION_SETFLAG, &rfc3339, 1},
     {"periodic_rtd", "Reset response time partition counters each logging interval.", SIPP_OPTION_SETFLAG, &periodic_rtd, 1},
 
     {"trace_msg", "Displays sent and received SIP messages in <scenario file name>_<pid>_messages.log", SIPP_OPTION_SETFLAG, &useMessagef, 1},
@@ -443,7 +459,7 @@ extern SIPpSocket  *sockets[SIPP_MAXFDS];
 static void sipp_sigusr1(int /* not used */)
 {
     /* Smooth exit: do not place any new calls and exit */
-    quitting+=10;
+    quitting += 10;
 }
 
 static void sipp_sigusr2(int /* not used */)
@@ -458,7 +474,7 @@ void timeout_alarm(int /*param*/)
     if (timeout_error) {
         ERROR("%s timed out after '%.3lf' seconds", scenario_file, ((double)clock_tick / 1000LL));
     }
-    quitting = 1;
+    quitting = 11;
     timeout_exit = true;
 }
 
@@ -510,16 +526,12 @@ static void traffic_thread(int &rtp_errors, int &echo_errors)
             sockets_pending_reset.erase(sockets_pending_reset.begin());
         }
 
-        if ((main_scenario->stats->GetStat(CStat::CPT_C_IncomingCallCreated) + main_scenario->stats->GetStat(CStat::CPT_C_OutgoingCallCreated)) >= stop_after) {
+        if (!quitting && (main_scenario->stats->GetStat(CStat::CPT_C_IncomingCallCreated) + main_scenario->stats->GetStat(CStat::CPT_C_OutgoingCallCreated)) >= stop_after) {
             quitting = 1;
         }
         if (quitting) {
-            if (quitting > 11) {
-                /* Force exit: abort all calls */
-                abort_all_tasks();
-            }
             /* Quitting and no more opened calls, close all */
-            if (!main_scenario->stats->GetStat(CStat::CPT_C_CurrentCall)) {
+            if ((quitting >= 11) || !main_scenario->stats->GetStat(CStat::CPT_C_CurrentCall)) {
                 /* We can have calls that do not count towards our open-call count (e.g., dead calls). */
                 abort_all_tasks();
                 rtp_errors = rtpstream_shutdown(main_scenario->fetchRtpTaskThreadIDs());
@@ -1084,9 +1096,9 @@ static void manage_oversized_file(int signum)
     fprintf(f,
             "-------------------------------------------- %s\n"
             "Max file size reached - no more logs\n",
-            CStat::formatTime(&currentTime));
+            CStat::formatTime(&currentTime, rfc3339));
 
-    fflush(f);
+    fclose(f);
     stop_all_traces();
     print_all_responses = 0;
     error_lfi.fptr = nullptr;
@@ -1194,28 +1206,6 @@ static void sighandle_set()
     sigaction(SIGXFSZ, &action_file_size_exceeded, nullptr);  // avoid core dump if the max file size is exceeded
 }
 
-static void set_scenario(const char* name)
-{
-    free(scenario_file);
-    free(scenario_path);
-
-    const char* sep = strrchr(name, '/');
-    if (sep) {
-        ++sep; // include slash
-        scenario_path = strndup(name, sep - name);
-    } else {
-        scenario_path = strdup("");
-        sep = name;
-    }
-
-    const char* ext = strrchr(sep, '.');
-    if (ext && strcmp(ext, ".xml") == 0) {
-        scenario_file = strndup(sep, ext - sep);
-    } else {
-        scenario_file = strdup(sep);
-    }
-}
-
 static int create_socket(struct sockaddr_storage* media_sa, int try_port, bool last_attempt,
                          const char *type)
 {
@@ -1334,6 +1324,48 @@ static void setup_media_sockets()
     }
 }
 
+/* Seed the random number generator from a combination of
+ * - Nanoseconds since epoch
+ * - Process ID
+ * - Hostname
+ */
+void randomseed(void)
+{
+    struct timespec ts;
+    time_t          seed          = time(nullptr);
+    char            hostname[256] = { 0 };
+    pid_t           p             = getpid();
+    int             index;
+
+    // If the system clock can provide us with a nanosecond count, then
+    // include that in the seed.
+    if (clock_gettime(CLOCK_MONOTONIC, &ts) == 0) {
+        seed ^= ts.tv_nsec;
+    }
+
+    // The system clock might not have nanosecond resolution, and so we still
+    // want to combine the seed with other values to avoid two
+    // near-simultaneous launches getting the same random seed.
+
+    if (p != 0) {
+        // We don't XOR with the PID because if we launch twice successively
+        // it's possible the PID increment could precisely counter the time
+        // increment.
+        seed *= p;
+    }
+
+    // Might truncate, or might leave 0s after the end.
+    gethostname(hostname, 256);
+
+    for (index = 0; index < 256; index++) {
+        // Bitflip with successive bytes of the hostname. Once we get to the
+        // 0s at the end it's a noop.
+        seed ^= (static_cast<uint64_t>(hostname[index]) << (8 * (index % sizeof(seed))));
+    }
+
+    srand(seed);
+}
+
 /* Main */
 int main(int argc, char *argv[])
 {
@@ -1346,7 +1378,7 @@ int main(int argc, char *argv[])
     rtp_errors = 0;
     echo_errors = 0;
 
-    srand(time(nullptr));
+    randomseed();
 
     /* At least one argument is needed */
     if (argc < 2) {
@@ -1526,6 +1558,28 @@ int main(int argc, char *argv[])
                 }
             }
             break;
+            case SIPP_OPTION_RX_INPUT_FILE:
+            {
+                REQUIRE_ARG();
+                CHECK_PASS();
+                FileContents *rxData = new FileContents(argv[argi]);
+                char *name = argv[argi];
+                if (strrchr(name, '/')) {
+                    name = strrchr(name, '/') + 1;
+                } else if (strrchr(name, '\\')) {
+                    name = strrchr(name, '\\') + 1;
+                }
+                assert(name);
+                inFiles[name] = rxData;
+                /* By default, the first file is used for IP address input. */
+                if (!rx_ip_file) {
+                    rx_ip_file = name;
+                }
+                if (!rx_default_file) {
+                    rx_default_file = name;
+                }
+            }
+            break;
             case SIPP_OPTION_INDEX_FILE:
                 REQUIRE_ARG();
                 REQUIRE_ARG();
@@ -1591,7 +1645,7 @@ int main(int argc, char *argv[])
                     break;
                 case 'c':
                     if (strlen(comp_error)) {
-                        ERROR("No " COMP_PLUGGIN " plugin available: %s", comp_error);
+                        ERROR("No " COMP_PLUGIN " plugin available: %s", comp_error);
                     }
                     transport = T_UDP;
                     compression = 1;
@@ -1699,17 +1753,14 @@ int main(int argc, char *argv[])
                 if (main_scenario) {
                     ERROR("Internal error, main_scenario already set");
                 } else if (!strcmp(argv[argi - 1], "-sf")) {
-                    set_scenario(argv[argi]);
                     if (useLogf == 1) {
                         rotate_logfile();
                     }
                     main_scenario = new scenario(argv[argi], 0);
-                    main_scenario->stats->setFileName(scenario_file, ".csv");
                 } else if (!strcmp(argv[argi - 1], "-sn")) {
                     int i = find_scenario(argv[argi]);
-                    set_scenario(argv[argi]);
                     main_scenario = new scenario(0, i);
-                    main_scenario->stats->setFileName(scenario_file, ".csv");
+                    main_scenario->setFileName(argv[argi]);
                 } else if (!strcmp(argv[argi - 1], "-sd")) {
                     int i = find_scenario(argv[argi]);
                     fprintf(stdout, "%s", default_scenario[i]);
@@ -1718,6 +1769,20 @@ int main(int argc, char *argv[])
                     ERROR("Internal error, I don't recognize %s as a scenario option", argv[argi] - 1);
                 }
                 break;
+            case SIPP_OPTION_RX_SCENARIO:
+                REQUIRE_ARG();
+                CHECK_PASS();
+                creationMode = MODE_MIXED;
+                if (!strcmp(argv[argi - 1], "-rxsf")) {
+                    rx_scenario = new scenario(argv[argi], 0);
+                } else if (!strcmp(argv[argi - 1], "-rxsn")) {
+                    int i = find_scenario(argv[argi]);
+                    rx_scenario = new scenario(0, i);
+                    rx_scenario->setFileName(argv[argi]);
+                } else {
+                    ERROR("Internal error, I don't recognize %s as a scenario option\n", argv[argi] - 1);
+                }
+                break;
             case SIPP_OPTION_OOC_SCENARIO:
                 REQUIRE_ARG();
                 CHECK_PASS();
@@ -1909,9 +1974,18 @@ int main(int argc, char *argv[])
         }
     }
 
+    /* generate random ssrc */
+    if (random_base_ssrc) {
+        global_ssrc_id = rand();
+    } else {
+        global_ssrc_id = 0xCA110000;
+    }
+
     /* Load compression plugin if needed/available. */
     if (compression) {
-        comp_load();
+        if (comp_load()) {
+            ERROR("Could not load " COMP_PLUGIN " plugin: %s", comp_error);
+        }
     }
 
     if ((extendedTwinSippMode && !slave_masterSet) || (!extendedTwinSippMode && slave_masterSet)) {
@@ -1934,13 +2008,12 @@ int main(int argc, char *argv[])
     }
 
     /* If no scenario was selected, choose the uac one */
-    if (scenario_file == nullptr) {
-        assert(main_scenario == nullptr);
+    if (!main_scenario) {
         int i = find_scenario("uac");
-        set_scenario("uac");
         main_scenario = new scenario(0, i);
-        main_scenario->stats->setFileName(scenario_file, ".csv");
+        main_scenario->setFileName("uac");
     }
+    scenario_file = main_scenario->getFileName().c_str();
 
 #ifdef USE_TLS
     if ((transport == T_TLS) && (TLS_init_context() != TLS_INIT_NORMAL)) {
@@ -2122,7 +2195,7 @@ int main(int argc, char *argv[])
 
     /* Setting the rate and its dependent params (open_calls_allowed) */
     /* If we are a client, then create the task to open new calls. */
-    if (creationMode == MODE_CLIENT) {
+    if (creationMode == MODE_CLIENT || creationMode == MODE_MIXED) {
         CallGenerationTask::initialize();
         CallGenerationTask::set_rate(rate);
     }
@@ -2179,7 +2252,5 @@ int main(int argc, char *argv[])
     free(epollevents);
 #endif
 
-    free(scenario_file);
-    free(scenario_path);
     sipp_exit(EXIT_TEST_RES_UNKNOWN, rtp_errors, echo_errors); // MAIN EXIT PATH HERE...);
 }
